@@ -1,3 +1,5 @@
 from manimlib.constants import *
+from itertools import chain, cycle
 
 color_list = [GREEN_C, BLUE_C, RED_C, YELLOW_C, ORANGE, GOLD_C, MAROON_C, TEAL_C]
+color_cycle = cycle(color_list)
