@@ -3,21 +3,22 @@ import time
 import sys
 from functools import wraps
 import shutil
-# from manimlib.utils.config_ops import digest_config
+import numpy as np
+from manimlib.utils.config_ops import digest_config
 # from manimlib.scene.scene_file_writer import SceneFileWriter
-from manimlib import Scene, Point, Camera, ShowCreation, Write, Color, VGroup
+from manimlib import Scene, Point, Camera, ShowCreation, Write, Color, VGroup, VMobject
 from manimlib.utils.rate_functions import linear, smooth
 from manimlib.extract_scene import get_scene_config
 import manimlib.config
+from manimlib.utils.color import rgb_to_hex
 from manimlib.config import Size
 from sparrow import ppath
-from .plot import Plot
+from .plot import Plot, PlotObj, xyz_to_points
 from .onlinetex import tex_to_svg_file_online
 import manimlib.mobject.svg.tex_mobject
 from pyglet.window import key
 
-
-__all__ = ["EagerModeScene", "JupyterModeScene", "Size", "SceneArgs"]
+__all__ = ["EagerModeScene", "JupyterModeScene", "Size", "SceneArgs", "PlotObj", "xyz_to_points"]
 
 
 class SceneArgs:
@@ -46,12 +47,12 @@ class SceneArgs:
 
 class EagerModeScene(Scene):
     def __init__(
-        self,
-        write_file=False,
-        file_name=None,
-        screen_size=Size.big,
-        scene_name='EagerModeScene',
-        CONFIG=None,
+            self,
+            write_file=False,
+            file_name=None,
+            screen_size=Size.big,
+            scene_name='EagerModeScene',
+            CONFIG=None,
     ):
         self.CONFIG = CONFIG
         args = manimlib.config.parse_cli()
@@ -83,6 +84,7 @@ class EagerModeScene(Scene):
 
         self.setup()
         self.plt = Plot()
+        self.is_axes_line_gen_ed = False
 
         self.clips = []
         self.current_clip = 1
@@ -93,10 +95,13 @@ class EagerModeScene(Scene):
         self.loop_start_animation = None
         self.pause_start_animation = 0
 
-    def play(self, *args, run_time=1, rate_func=smooth, **kwargs):
+    def play(self, *args, run_time=1, rate_func=linear, **kwargs):
         """TODO:"""
         super().play(*args, run_time=run_time, rate_func=rate_func, **kwargs)
-    
+
+    # def clip1(self):
+    #     pass
+
     def get_animate_name_func(self, n=10):
         animation_func_dict = {}
         for i in range(n):
@@ -107,7 +112,7 @@ class EagerModeScene(Scene):
             except:
                 continue
         self.animation_func_dict = animation_func_dict
-            
+
     def render(self):
         self.get_animate_name_func()
         for name, func in self.animation_func_dict.items():
@@ -121,9 +126,9 @@ class EagerModeScene(Scene):
     def replay(self, animation_index=None):
         if animation_index is None:
             animation_index = self.current_clip
-        self.saved_state = self.saved_states[animation_index-1]
+        self.saved_state = self.saved_states[animation_index - 1]
         self.restore()
-        self.animation_list[animation_index-1]()
+        self.animation_list[animation_index - 1]()
 
     def loop_animate(self, animation_index=None, num=10):
         while num:
@@ -182,6 +187,7 @@ class EagerModeScene(Scene):
     def embed(self):
         super().embed()
 
+    # FIXME: Remove method `plot` from EagerModeScene.
     def plot(self,
              x,
              y,
@@ -189,7 +195,7 @@ class EagerModeScene(Scene):
              width=2,
              axes_ratio=0.62,
              scale_ratio=None,
-             num_decimal_places=(1, 1),
+             num_decimal_places=None,
              show_axes=True,
              include_tip=True,
              x_label='x',
@@ -210,33 +216,38 @@ class EagerModeScene(Scene):
         pass
 
     def get_plot_mobj(self):
-        self.plt.gen_axes_lines()
-        return self.plt.get_axes_lines()
+        if self.is_axes_line_gen_ed is False:
+            self.plt.gen_axes_lines()
+        self.is_axes_line_gen_ed = True
+        axes_lines_dict = self.plt.get_axes_lines()
+        axes_mobj = VGroup(*axes_lines_dict["axes"])
+        lines_mobj = VGroup(*axes_lines_dict["line"])
+        return axes_mobj, lines_mobj
 
     def get_plot_axes(self):
         return self.plt.get_axes()
 
     def reset_plot(self):
         self.plt = Plot
+        self.is_axes_line_gen_ed = False
 
     def show_plot(self, play=True, reset=True):
-        axes_lines_dict = self.get_plot_mobj()
-
+        axes_mobj, lines_mobj = self.get_plot_mobj()
         random.seed(time.time())
         if play:
             def play_func(Func):
-                if axes_lines_dict['axes']:
-                    self.play(ShowCreation(VGroup(*axes_lines_dict["axes"])),
-                              run_time=1)
-                self.play(Func(VGroup(*axes_lines_dict["line"])), run_time=1)
+                if len(axes_mobj):
+                    self.play(ShowCreation(axes_mobj),
+                              run_time=1, rate_func=smooth)
+                self.play(Func(lines_mobj), run_time=1, rate_func=smooth)
 
             if random.random() > 0.5:
                 play_func(Write)
             else:
                 play_func(ShowCreation)
         else:
-            self.add(VGroup(*axes_lines_dict["line"],
-                            *axes_lines_dict["axes"]))
+            self.add(VGroup(axes_mobj,
+                            lines_mobj))
 
         if reset:
             self.plt = Plot()
@@ -256,4 +267,3 @@ class JupyterModeScene(EagerModeScene):
     def quit(self):
         """Please use exit() or quit() in jupyter cell."""
         pass
-
